@@ -1,9 +1,9 @@
 from .imshow import imshow
 from .log_graph import log_graph
-from . import web
+from . import watcher
 
 __all__ = [
     "imshow",
     "log_graph",
-    "web"
+    "watcher"
 ]
